


# Author: Jack C. Olson, Smithsonian Institution, Tenenbaum Marine Observatory Network, Marine Global Earth Observatory
# Date: 10/19/2022
# email: Olson.jackc@gmail.com



# The following script contains code to recreate analyses of size and abundance data collected in 2015-2016 by researchers from the Marine Global Earth Observatory (MarineGEO). All code is original. Basic analysis steps are as follows:

#               > calculate fish densities (fish/m^2)
#               > calculate log-transformed and centered size-spectra for every survey
#               > fit models of size-spectra intercept and slope according to AICc and residual diagnostics tests

#               > define function to create models and perform Dunnett's test of structured habitat effects vs. soft sediment effects by location

#               > define function to calculate and clean estimated marginal means from slope and intercept models.

#               > run both functions on size-spectra dataframe to obtain Dunnett's test results and model-predicted responses and calculate 95% confidence intervals.

#               > create fish density and total length boxplots by location and habitat type

#               > create summary tables of fish density, length, and benthic area surveyed by habitat type and location

#               > organize school abundance data and create visualizations of small fish (<100mm) school density (schools/m2)


#*********************************************************************************************************
## load libraries

library(tidyverse)
library(janitor)
library(emmeans)
library(MuMIn)
library(DHARMa)
library(tidyverse)
library(dplyr)
library(lme4)
library(ggplot2)
library(emmeans)
library(broom)
library(lubridate)
library(cowplot)

options(scipen = 999)

## read in raw fish survey data with lengths and abundances estimated using DIDSON host software (Sound Metrics Corporation)


sonar_fish <- read.csv("SI_DIDSON_fish_data_2015_2016.csv")

### Columns in 'sonar_fish' are as follows:

#   'id' = vector of survey identifiers with location, sampling site, habitat type, and transect number
#   'date' = date when DIDSON sonar surveys were conducted
#   'location' = geographic sampling location. 'bocas' = Bocas del Toro, Panama; 'sms' = Fort Pierce, Florida; 'rb' = Richardson Bay CA; 'rr' = Rhode River, Maryland.
#   'site'= sampling site name
#   'habitat'= habitat type sampled. Note: "soft" denotes soft sediment and "reef" denotes "coral reef"
#   'transect_no' = replicate transect number completed per site and location
#   'size_class' = size class midoints in mm. Size classes were: 110-125mm, 125-150mm, 150-175mm, 175-200mm, 200-225mm, 225-250mm, 250-275mm, 275-300mm, 300-325mm, 325-350mm, 350-375mm, 375-400mm
#   'area_m2' = two dimensional area (m^2) of the benthos surveyed by sonar in each transect. Calculated from the sonar beam with at intersection with the bottom and length of transect. 
#   'number' = number of fish counted in each survey, by size class



## calculate fish density per m^2 for each sonar survey

sonar_fish <- sonar_fish %>%
  group_by(id,location, site, habitat, transect_no, size_class,area_m2,number) %>% 
  summarise(dens_m2 = number/area_m2) %>% 
  ungroup()


## ln(x +1) transform the density data, and ln() transform the size class midpoints (per Daan et al. 2005)

log_spectra <- sonar_fish %>% 
  group_by(location, site, habitat, transect_no, size_class) %>%
  mutate(ln_dens = log(dens_m2+1),log_size = log(size_class)) %>% 
  ungroup()


## center the size class midpoints

log_spectra$scale_sizes <- scale(log_spectra$log_size, scale = F)




## pair down data to only neccessary columns

log_spectra <- log_spectra %>% 
  dplyr::select(location,site,habitat,transect_no,scale_sizes,log_size,ln_dens)

write.csv(log_spectra, file = "SI_didson_raw_size_spectra.csv", row.names = F)

# create nested data frame

lm_nest <- log_spectra %>% 
  group_by(location,site,habitat,transect_no) %>% 
  nest()

## define lm function
library(broom)

## define function to create linear regression of ln(density + 1) by ln-transformed and centered size class midpoints

spectra_model <- function(df){
  lm(ln_dens ~ scale_sizes,data = df)
}


## turn off scientific notation

options(scipen = 999)

## apply linear model function over nested data frame and add within df with mutate

lm_nest <- lm_nest %>% 
  mutate(model = map(data,spectra_model)) %>% 
  mutate(model = map(model,tidy)) %>% 
  unnest(model)

## remove nested data column and other unneccessary columns
lm_nest <- lm_nest %>% 
  dplyr::select(-c(data,p.value,std.error,statistic))

## create vectors for spectra intercept '(Intercept)' and slope ('scale_sizes')
lm_nest <- spread(lm_nest, key = "term", value = "estimate")


# rename columns
lm_nest <- lm_nest %>% 
  rename(Intercept = `(Intercept)`,
         size_slope = scale_sizes)


#************************************************************************************************************
#************************************************************************************************************
#*********************************************************************************************************************
## visualize size-spectra by replicate, habitat type, and sampling location

# read in log-transformed size-spectra produced above (line 95)
raw_spectra <- read.csv("SI_didson_raw_size_spectra.csv")


#raw_spectra <- read.csv("log_spectra_12_13_22.csv")
raw_spectra$survey <- paste(raw_spectra$location, raw_spectra$site, raw_spectra$habitat, raw_spectra$transect_no, sep = "_")


raw_spectra <- raw_spectra %>%
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove/woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef/rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "soft" ~ "soft sediment",
    TRUE ~ habitat
  ))

raw_spectra$habitat <- factor(raw_spectra$habitat)

raw_spectra <- raw_spectra %>%
  mutate(location = case_when(
    location == "rb" ~ "Richardson Bay, CA",
    location == "sms" ~ "Ft. Pierce, FL",
    location == "rr" ~ "Rhode River, MD",
    location == "bocas" ~ "Bocas del Toro, PAN"
  ))

# need to add 'NA' values to 'raw spectra' dataframe to account for habitat types not sampled in individual locations (e.g., SAV at Rhode River)

# get 
colnames(raw_spectra)
# "location"    "site"        "habitat"     "transect_no" "scale_sizes" "log_size"  "ln_dens" "survey"     


# create 'NA_df'

location <- c("Bocas del Toro, PAN", "Richardson Bay, CA", "Rhode River, MD")
site <- c(NA,NA,NA)
habitat <- c("SAV","biogenic reef/rock","mangrove/woody debris")
transect_no <- c(1,1,1)
scale_size  <- as.numeric(c(NA,NA,NA))
log_size <- as.numeric(c(NA,NA,NA))
ln_dens <- as.numeric(c(NA,NA,NA))
survey <- as.character(c("1","1","1"))

na_df <- data.frame(bind_cols(location,site,habitat,transect_no,scale_size,log_size,ln_dens,survey))

# assign column names to match 'raw_spectra' df 
colnames(na_df) <- colnames(raw_spectra)

# bind NA_df with raw_spectra
raw_spectra <- bind_rows(raw_spectra,na_df)

# rename habitat column
raw_spectra <- raw_spectra%>% 
  rename(Habitat = habitat)


# assign habitat factor levels for plotting
raw_spectra$Habitat <-  factor(raw_spectra$Habitat, levels = c("dock","mangrove/woody debris","biogenic reef/rock","SAV","soft sediment"))


spectra <-ggplot(raw_spectra, aes(x = log_size, y = ln_dens, group = survey)) + stat_smooth(se = T, method = "lm", aes(color = Habitat, fill = Habitat),fullrange = T, size = 0.45, alpha = 0.22) + xlab("ln(size class)") +  ylab("ln(density + 1)") + theme_bw() + facet_grid(cols = vars(location)) + theme(strip.text.x = element_text(size = 9)) + scale_y_continuous(expand = c(0,0)) + theme(panel.grid = element_blank()) + scale_x_continuous(limits = c(4.7,6)) + scale_color_manual(breaks = levels(raw_spectra$Habitat), values= c("#A71B4B","yellow3","#F39B40","#22C4B3","#584B9F")) + scale_fill_manual("",breaks = levels(raw_spectra$Habitat), values= c("#A71B4B","yellow3","#F39B40","#22C4B3","#584B9F")) + theme(axis.title = element_text(size = 10), legend.box.background = element_rect(color = "black", size = 1), strip.background.x = element_rect(fill = "white"), legend.title = element_text(size = 12), legend.text = element_text(size = 10), legend.position = "top", legend.key.height = unit(0.02, "cm"), legend.key.width = unit(0.6, "cm")) + guides(color = guide_legend(override.aes = list(size = 3),nrow = 2),fill = "none") + theme(axis.text = element_text(size = 8, color = "black")) + theme(text = element_text(family = "helvetica"))

spectra

#*********************************************************************************************************************
#*********************************************************************************************************************

## slope model fitting ##

## define cube root function for transformation of slopes 

CubeRoot<-function(x){
  sign(x)*abs(x)^(1/3)
}
# 

## create cube root slope column. Prior anaylses identified cube transformation as the most appropriate to satisfy the assumption of normality of errors and homoscedascity. 

lm_nest <- lm_nest %>%
  mutate(cube_rt_slope = CubeRoot(size_slope))


# change "seagrass" to "sav" within habitat column

lm_nest <- lm_nest %>%
  mutate(habitat = case_when(
    habitat == "seagrass" ~"sav",
    TRUE ~ habitat
  ))


mod1 <- lmer(cube_rt_slope ~ location/habitat + (1|site) + (1|transect_no), data = lm_nest)
AICc(mod1)
#38.7581

simres1 <- simulateResiduals(mod1)
plot(simres1)


#******************
mod1.1 <- lmer(cube_rt_slope ~ location/habitat + (1|site/transect_no), data = lm_nest)
AICc(mod1.1)

# singular fit -- over parameterized 


#***********************
mod1.2 <- lmer(cube_rt_slope ~ location/habitat + (1|site), data = lm_nest)
AICc(mod1.2)
#35.87216

simres1.2 <- simulateResiduals(mod1.2)
plot(simres1.2)
testDispersion(simres1.2)
### looks good 


mod1.3 <- lm(cube_rt_slope ~ location/habitat, data = lm_nest)
AICc(mod1.3)
#-21.72516 <<<< best

simres1.3 <- simulateResiduals(mod1.3)

plot(simres1.3)

# testDispersion(mod1.3)
# DHARMa nonparametric dispersion test via sd of residuals fitted vs. simulated
# 
# data:  simulationOutput
# dispersion = 0.86342, p-value = 0.304
# alternative hypothesis: two.sided

testZeroInflation(simres1.3)

# DHARMa zero-inflation test via comparison to expected zeros with simulation under H0 = fitted model
# 
# data:  simulationOutput
# ratioObsSim = NaN, p-value = 1
# alternative hypothesis: two.sided



##******************************************************************************************************************************
#********************************************************************************************************************************


## intercept model fitting 

#*****************************


mod1_int <- lmer(log(Intercept) ~ location/habitat + (1|site) + (1|transect_no), data = lm_nest)
## singular fit


#******************
mod1.1_int <- lmer(log(Intercept) ~ location/habitat + (1|site/transect_no), data = lm_nest)

# singular fit


#***********************
mod1.2_int <- lmer(log(Intercept) ~ location/habitat + (1|site), data = lm_nest)
# singular fit


mod1.3_int <- lm(log(Intercept) ~ location/habitat, data = lm_nest)
AICc(mod1.3_int)
#374.7611

simres1.3_int <- simulateResiduals(mod1.3_int)

plot(simres1.3_int)

testDispersion(mod1.3_int)
#data:  simulationOutput
#dispersion = 0.86342, p-value = 0.304
#alternative hypothesis: two.sided

testZeroInflation(simres1.3_int)

# DHARMa zero-inflation test via comparison to expected zeros with simulation under H0 = fitted model
# 
# data:  simulationOutput
# ratioObsSim = NaN, p-value = 1
# alternative hypothesis: two.sided




#***************************************************************************************************************************
#***************************************************************************************************************************
# Define function to calculate estimated marginal means by location and habitat from (previously fit) slope and intercept models, then run Dunnett's test of multiple treatments (structured habitats) against a single control (soft sediment). Clean the resulting model object using broom::tidy() which creates a model output table. 




nested_mod_fun <- function(df){
  # define and run models of slope and intercept
  slope_mod <- lm(CubeRoot(size_slope) ~ location/habitat, data = df)
  int_mod <- lm(log(Intercept) ~ location/habitat, data = df)
  
  # create emmGrid object
  slope_grid <- emmeans::emmeans(slope_mod, ~location/habitat)
  
  #run Dunnett's post hoc test by location on emmGrid slope object, with control ('ref') set as "soft" (soft sediment)
  
  slope_dun <- emmeans::contrast(slope_grid, method = "dunnett", ref = "soft", by = "location")
  
  ## same routine for intercept model
  int_grid <- emmeans::emmeans(int_mod,~location/habitat)
  int_dun <- emmeans::contrast(int_grid, method = "dunnett", ref = "soft", by = "location")
  
  ## clean output of Dunnett's test for each response variable
  int_dun <- broom::tidy(int_dun)
  slope_dun <- broom::tidy(slope_dun)
  
  # add response variable column to both data frames
  int_dun$response <- "intercept"
  slope_dun$response <- "slope"
  
  # bind data frames
  dunnetts_both <- bind_rows(slope_dun,int_dun)
  
  # round numeric columns to 4 digits
  dunnetts_both <- dunnetts_both %>%
    mutate_if(is.numeric, ~round(., 4))
  
  return(dunnetts_both)}


## Run function on nested data frame to produce results of Dunnett's test for both response variables across all locations and structured habitats. 

dunnetts_results_sonar_fish <- nested_mod_fun(lm_nest)



# Define function to calculate estimated marginal mean spectra slope and height by location and habitat for plotting. Use tidy() to create model table.  


nested_emmeans <- function(x){
  
  slope_mod <- lm(CubeRoot(size_slope) ~ location/habitat, data = x)
  int_mod <- lm(log(Intercept) ~ location/habitat, data = x)
  
  slope_grid <- emmeans(slope_mod,~location/habitat)
  int_grid <- emmeans(int_mod,~location/habitat)
  
  slope_grid <- tidy(slope_grid)
  int_grid <- tidy(int_grid)
  
  int_grid$response <- "intercept"
  slope_grid$response <- "slope"
  
  
  em_both <- bind_rows(slope_grid,int_grid)
  em_both <- em_both %>%
    mutate_if(is.numeric, ~round(., 4))
  
  
  return(em_both)}



# run nested emmeans function 
emmeans_sonar_fish <- nested_emmeans(lm_nest)


# calculate 95% confidence intervals of estimated marginal means

emmeans_sonar_fish$upr.cl <- emmeans_sonar_fish$estimate + (1.96 * emmeans_sonar_fish$std.error)
emmeans_sonar_fish$lwr.cl <- emmeans_sonar_fish$estimate - (1.96 * emmeans_sonar_fish$std.error)


#*********************************************************************************************************
#*********************************************************************************************************
#*********************************************************************************************************
#*********************************************************************************************************
#*********************Fish density and length summary value calculation and visualization ****************


dens_spect <- clean_names(read.csv("SI_DIDSON_raw_abundance_2015_2016.csv"))


## calculate density_m2 from abundance ('number') and benthic area surveyed (area_m2) by transect ID ('id')

dens <- dens_spect %>%
  group_by(id) %>% 
  mutate(sum_n = sum(number), dens_m2 = sum_n/area_m2) %>% 
  ungroup()


dens <- dens %>% 
  dplyr::select(id,location, site, habitat, transect_no,dens_m2) %>% 
  unique()


dens <- dens %>%
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove and woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef and rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "soft" ~ "soft sediment",
    habitat == "docks" ~ "dock",
    habitat == "sav" ~ "SAV",
    TRUE ~ habitat
  ))


dens <- dens %>%
  mutate(location = case_when(
    location == "rb" ~ "Richardson Bay, CA",
    location == "sms" ~ "Ft. Pierce, FL",
    location == "rr" ~ "Rhode River, MD",
    location == "bocas" ~ "Bocas del Toro, PAN"
  ))

dens <- filter(dens, !(location == "Bocas del Toro, PAN" & habitat == "SAV"))


habs <- factor(c("biogenic reef and rock","dock","mangrove and woody debris","SAV","soft sediment"))



x = bquote('x axis'~(^2))

dens_summary <- dens %>% 
  group_by(location, habitat) %>% 
  summarise(mean_dens = mean(dens_m2), se = sd(dens_m2)/sqrt(length(.))) %>% 
  ungroup()

dens_summary_loc <- dens %>% 
  group_by(location) %>% 
  summarise(mean_dens = mean(dens_m2), se = sd(dens_m2)/sqrt(length(.))) %>% 
  ungroup()


#dens <- bind_rows(dens,na_df)

p1 <- ggplot(dens, aes(x = location, y = dens_m2)) + geom_boxplot(outlier.size = 0.75,lwd = 0.3) + xlab(NULL) + ylab(bquote('Density' ~('fish'/m^2))) + theme_bw() +theme(axis.text.x = element_text(size = 10, angle = 50, hjust = 1, color = "black"), axis.title.y = element_text(size = 14)) + scale_x_discrete(position = "bottom")+ theme(panel.grid = element_blank()) + theme(text = element_text(family = "helvetica"))



p1


p2 <- ggplot(dens, aes(x = habitat, y = dens_m2)) + geom_boxplot(aes(fill= habitat),outlier.size = 0.75, lwd = 0.3) + scale_x_discrete(breaks = habs, drop = FALSE)+facet_wrap(~location, scales = "free_x") + theme_bw() + theme(axis.text.x= element_blank(),axis.ticks.x = element_blank(),strip.background.x = element_rect(fill= "white"), axis.title.y = element_text(size = 16)) + xlab(NULL) + scale_fill_manual("",values = c("#A71B4B","#F39B40","yellow3","#22C4B3","#584B9F"), breaks = levels(habs)) + theme(legend.text = element_text(size = 8), legend.position = "bottom", legend.key.height = unit(0.5, "cm"), legend.key.width = unit(0.3, "cm"),legend.spacing.x = unit(0.18,"cm"),strip.text.x = element_text(size = 10)) + guides(fill = guide_legend(nrow = 3)) + theme(axis.title.y = element_blank()) + theme(panel.grid = element_blank())

p2

library(cowplot)

p3 <- plot_grid(p1, p2, rel_widths = (c(0.85,1)), align = "hv", axis = 'tb')

p3

#*******************************************************************************************************
#********************************************************************************************************
##*******************************************************************************************************
##                             Total length boxplots

lengths <- read.csv("SI_DIDSON_raw_lengths_2015_2016.csv")

## reassign habitat names
lengths <- lengths %>%
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove and woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef and rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "soft" ~ "soft sediment",
    habitat == "docks" ~ "dock",
    habitat == "sav" ~ "SAV",
    TRUE ~ habitat
  ))

# reassign location names


lengths <- lengths %>%
  mutate(location = case_when(
    location == "richardson bay" ~ "Richardson Bay, CA",
    location == "ft pierce" ~ "Ft. Pierce, FL",
    location == "rhode river" ~ "Rhode River, MD",
    location == "bocas del toro" ~ "Bocas del Toro, PAN"
  ))

## filter out Bocas del Toro, SAV due to few fish and subsequent exclusion from analyses

lengths <- filter(lengths, !(location == "Bocas del Toro, PAN" & habitat == "SAV"))

# define habitat factor levels

habs <- factor(c("biogenic reef and rock","dock","mangrove and woody debris","SAV","soft sediment"))


## create box plot of total length by location


p1 <- ggplot(lengths, aes(x = location, y = length/10)) + geom_boxplot(outlier.size = 0.75,lwd = 0.4) + xlab(NULL) + ylab("Total length (cm)") + theme_bw() + theme(axis.text.x = element_text(size = 10, angle = 50, hjust = 1, color = "black"), axis.title.y = element_text(size = 14)) + scale_x_discrete(position = "bottom") + theme(text = element_text(family = "helvetica")) + theme(panel.grid = element_blank())

p1

# create boxplot of total length by location and habitat

p2 <- ggplot(lengths, aes(x = habitat, y = length/10)) + geom_boxplot(aes(fill= habitat),outlier.size = 0.75, lwd = 0.3) + scale_x_discrete(breaks = habs, drop = FALSE)+facet_wrap(~location, scales = "free_x") + theme_bw() + theme(axis.text.x= element_blank(),axis.ticks.x = element_blank(),strip.background.x = element_rect(fill= "white"), axis.title.y = element_text(size = 16)) + ylab("Total length (cm)") + xlab(NULL) + scale_fill_manual("",values = c("#A71B4B","#F39B40","yellow3","#22C4B3","#584B9F"), breaks = levels(habs)) + theme(legend.text = element_text(size = 8), legend.position = "bottom", legend.key.height = unit(0.5, "cm"), legend.key.width = unit(0.3, "cm"),legend.spacing.x = unit(0.18,"cm"),strip.text.x = element_text(size = 10)) + guides(fill = guide_legend(nrow = 3)) + theme(axis.title.y = element_blank()) + scale_x_discrete(position = "bottom") + theme(text = element_text(family = "helvetica")) + theme(panel.grid = element_blank())

library(cowplot)


# combine boxplots 

p3 <- plot_grid(p1, p2, rel_widths = (c(0.85,1)), align = "hv", axis = 'tb')

p3

#ggsave(p3, file = "len_box_08_16_22.tiff", width  = 169 , height = 120, units = "mm", dpi = 300)


#*************************************************************************************************************
#                             Create summary tables of length, abundance, density, and benthic area surveyed by habitat type and location


lengths <- read.csv("SI_DIDSON_raw_lengths_2015_2016.csv")

lengths <- lengths %>%
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove and woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef and rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "soft sediment" ~ "soft",
    habitat == "docks" ~ "dock",
    habitat == "sav" ~ "SAV",
    TRUE ~ habitat
  ))


lengths <- lengths %>%
  mutate(location = case_when(
    location == "richardson bay" ~ "Richardson Bay, CA",
    location == "ft pierce" ~ "Ft. Pierce, FL",
    location == "rhode river" ~ "Rhode River, MD",
    location == "bocas del toro" ~ "Bocas del Toro, PAN"
  ))

## filter out Bocas del Toro, SAV due to few fish and subsequent exclusion from analysis
lengths <- filter(lengths, !(location == "Bocas del Toro, PAN" & habitat == "SAV"))


## create summary data frame of mean and SE length by habitat and location 
len_sum <- lengths %>% 
  group_by(location,habitat) %>% 
  summarise(mean_len = mean(length)/10, se_l = ((sd(length)/sqrt(length(.)))/10)) %>%
  mutate_if(is.numeric, ~round(., 1)) %>% 
  ungroup()



### density summary table


dens_spect <- clean_names(read.csv("SI_DIDSON_raw_abundance_2015_2016.csv"))

# isolate benthic area into separate dataframe, and create summary by habitat and location

area_hab_loc <- dens_spect %>% 
  dplyr::select(id,location,habitat,area_m2) %>% 
  unique()

area_hab_loc <- area_hab_loc %>% 
  group_by(location,habitat) %>% 
  summarise(mean_benthic_area = mean(area_m2), se_area = sd(area_m2)/sqrt(length(.))) %>%
  mutate_if(is.numeric, ~ round(.,digits = 2)) %>% 
  ungroup()

## calculate density_m2 

## calculate total density per transect ('id')

dens <- dens_spect %>%
  group_by(id) %>% 
  mutate(sum_n = sum(number), dens_m2 = sum_n/area_m2) %>% 
  ungroup()

# isolate columns of interest
dens <- dens %>% 
  dplyr::select(id,location, site, habitat, transect_no,dens_m2,sum_n) %>% 
  unique()

## change names of habitat types for clarity

dens <- dens %>%
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove and woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef and rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "soft sediment" ~ "soft",
    habitat == "docks" ~ "dock",
    habitat == "sav" ~ "SAV",
    TRUE ~ habitat
  ))

# same for area dataframe

area_hab_loc <- area_hab_loc %>% 
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove and woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef and rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "soft sediment" ~ "soft",
    habitat == "docks" ~ "dock",
    habitat == "sav" ~ "SAV",
    TRUE ~ habitat
  ))

# change location names for clarity in density dataframe

dens <- dens %>%
  mutate(location = case_when(
    location == "rb" ~ "Richardson Bay, CA",
    location == "sms" ~ "Ft. Pierce, FL",
    location == "rr" ~ "Rhode River, MD",
    location == "bocas" ~ "Bocas del Toro, PAN"
  ))

# same for area dataframe


area_hab_loc <- area_hab_loc %>% 
  mutate(location = case_when(
    location == "rb" ~ "Richardson Bay, CA",
    location == "sms" ~ "Ft. Pierce, FL",
    location == "rr" ~ "Rhode River, MD",
    location == "bocas" ~ "Bocas del Toro, PAN"
  ))



habs <- factor(c("biogenic reef and rock","dock","mangrove and woody debris","SAV","soft"))



dens_summary <- dens %>% 
  group_by(location, habitat) %>% 
  summarise(mean_dens = mean(dens_m2), se_d = sd(dens_m2)/sqrt(length(.)), mean_n = mean(sum_n), se_n = sd(sum_n)/sqrt(length(.))) %>%
  mutate_if(is.numeric, ~round(., 2)) %>% 
  ungroup()



#***********
#*********
#* join length, density, and benthic area summary dataframes by location and habitat type


full_summary_habloc <- left_join(len_sum, dens_summary, by = c("location","habitat"))

full_summary_habloc <- left_join(full_summary_habloc, area_hab_loc, by = c("habitat","location"))




#*********************************************************************************************************
#*********************************************************************************************************
#*********************************************************************************************************
#*********************************************************************************************************
#***************************** Small, schooling fish data processing and visualization *******************



## Code below is to organize and create visualizations of small fish school abundance by habitat type and location


# read in dataframe with small fish (< 100mm ) school abundance containing school abundances for each DIDSON transect conducted at Bocas del Toro, Panama, Rhode River, Maryland, Richardson Bay, California, and Fort Pierce, Florida. School abundance delineated by coarse estimates of the numbers of fish in each school (i.e., > 50 individuals and < 50 individuals)


sm_fish_schools <- read.csv("SI_DIDSON_sm_fish_schools_2015_2016.csv")


# change habitat names to conform with other analyses

sm_fish_schools <- sm_fish_schools %>%
  mutate(habitat = case_when(
    habitat %in% c("woody debris","mangrove") ~ "mangrove/woody debris",
    habitat %in% c("reef","oyster reef","rock") ~ "biogenic reef/rock",
    habitat == "seagrass" ~ "SAV",
    habitat == "sav" ~ "SAV",
    habitat == "docks" ~ "dock",
    habitat == "soft" ~ "soft sediment",
    TRUE ~ habitat
  ))

# change habitat column to factor 

sm_fish_schools$habitat <- factor(sm_fish_schools$habitat)

# change location names to match other analyses

sm_fish_schools <- sm_fish_schools %>%
  mutate(location = case_when(
    location == "richardson bay" ~ "Richardson Bay, CA",
    location == "ft pierce" ~ "Ft. Pierce, FL",
    location == "rhode river" ~ "Rhode River, MD",
    location == "bocas del toro" ~ "Bocas del Toro, PAN"
  ))

# sum small (< 50 individuals) and large (> 50 individuals) by transect

sm_fish_schools <- sm_fish_schools %>%
  group_by(filename) %>%
  mutate(tot_schools = sum(less_50, greater_50))


habs <- factor(c("biogenic reef/rock","dock","mangrove/woody debris","SAV","soft sediment"))

## calculate school density (schools / m^2) for each transect

sm_fish_schools <- sm_fish_schools  %>% 
  mutate(sch_dens = tot_schools/area_m2)



sm_fish_box <- ggplot(sm_fish_schools, aes(x = habitat, y = sch_dens)) + geom_boxplot(aes(fill = habitat)) + scale_y_continuous(expand= c(0,0))+ ylab(bquote('School density ' ~ ('schools'/m^2))) + scale_x_discrete(breaks = habs, drop = T) +facet_wrap(~location, scales = "free_x") + theme_bw() + theme(strip.background.x = element_rect(fill= "white"), axis.title.y = element_text(size = 16), axis.ticks = element_blank()) + xlab(NULL) + scale_fill_manual("",values = c("#A71B4B","#F39B40","yellow3","#22C4B3","#584B9F"), breaks = levels(habs))+theme(legend.text = element_text(size = 8), legend.position = "top", legend.key.height = unit(0.5, "cm"), legend.key.width = unit(0.3, "cm"),legend.spacing.x = unit(0.18,"cm"),strip.text.x = element_text(size = 10)) + guides(fill = guide_legend(nrow = 2)) +coord_cartesian(ylim = c(0,0.25)) + theme(panel.grid = element_blank()) + theme(axis.text.x = element_blank())+ theme(text = element_text(family = "helvetica"))

sm_fish_box



